@@ -2,4 +2,7 @@ from . import io
 from . import process
 from . import analysis
 from . import driftspeed
-from .SPMImage import SPMImage
\ No newline at end of file
+
+from .SPMImage import SPMImage
+from .io import read
+from .process import correct, flatten
\ No newline at end of file
